@@ -682,6 +682,23 @@ sub DistinctQuery {
 
 # }}}
 
+
+
+=head2 DESTROY
+
+When we get rid of the Searchbuilder::Handle, we need to disconnect from the database
+
+=cut
+
+  
+sub DESTROY {
+  my $self = shift;
+  if( defined $self->dbh ) {
+    $self->Disconnect();
+  }
+}
+
+
 1;
 __END__
 
